<?php
if (!isset($__jalali_inc_)) { $__jalali_inc_ = 1;

include("misc.inc");
include("farsi.inc");

$g_days_in_month = array(31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
$j_days_in_month = array(31, 31, 31, 31, 31, 31, 30, 30, 30, 30, 30, 29);

function gregorian_to_jalali($g_y, $g_m, $g_d)
{
   global $g_days_in_month;
   global $j_days_in_month;
   
   $gy = $g_y-1600;
   $gm = $g_m-1;
   $gd = $g_d-1;

   $g_day_no = 365*$gy+div($gy+3,4)-div($gy+99,100)+div($gy+399,400);

   for ($i=0; $i < $gm; ++$i)
      $g_day_no += $g_days_in_month[$i];
   if ($gm>1 && (($gy%4==0 && $gy%100!=0) || ($gy%400==0)))
      /* leap and after Feb */
      $g_day_no++;
   $g_day_no += $gd;

   $j_day_no = $g_day_no-79;

   $j_np = div($j_day_no, 12053); /* 12053 = 365*33 + 32/4 */
   $j_day_no = $j_day_no % 12053;

   $jy = 979+33*$j_np+4*div($j_day_no,1461); /* 1461 = 365*4 + 4/4 */

   $j_day_no %= 1461;
 
   if ($j_day_no >= 366) {
      $jy += div($j_day_no-1, 365);
      $j_day_no = ($j_day_no-1)%365;
   }
 
   for ($i = 0; $i < 11 && $j_day_no >= $j_days_in_month[$i]; ++$i)
      $j_day_no -= $j_days_in_month[$i];
   $jm = $i+1;
   $jd = $j_day_no+1;

   return array($jy, $jm, $jd);
}

function gregorian_week_day($g_y, $g_m, $g_d)
{
   global $g_days_in_month;

   $gy = $g_y-1600;
   $gm = $g_m-1;
   $gd = $g_d-1;

   $g_day_no = 365*$gy+div($gy+3,4)-div($gy+99,100)+div($gy+399,400);

   for ($i=0; $i < $gm; ++$i)
      $g_day_no += $g_days_in_month[$i];
   if ($gm>1 && (($gy%4==0 && $gy%100!=0) || ($gy%400==0)))
      /* leap and after Feb */
      ++$g_day_no;
   $g_day_no += $gd;

   return ($g_day_no + 5) % 7 + 1;
}

function jalali_to_gregorian($j_y, $j_m, $j_d)
{
   global $g_days_in_month;
   global $j_days_in_month;
   
   $jy = $j_y-979;
   $jm = $j_m-1;
   $jd = $j_d-1;

   $j_day_no = 365*$jy + div($jy, 33)*8 + div($jy%33+3, 4);
   for ($i=0; $i < $jm; ++$i)
      $j_day_no += $j_days_in_month[$i];

   $j_day_no += $jd;

   $g_day_no = $j_day_no+79;

   $gy = 1600 + 400*div($g_day_no, 146097); /* 146097 = 365*400 + 400/4 - 400/100 + 400/400 */
   $g_day_no = $g_day_no % 146097;

   $leap = true;
   if ($g_day_no >= 36525) /* 36525 = 365*100 + 100/4 */
   {
      $g_day_no--;
      $gy += 100*div($g_day_no,  36524); /* 36524 = 365*100 + 100/4 - 100/100 */
      $g_day_no = $g_day_no % 36524;
      
      if ($g_day_no >= 365)
         $g_day_no++;
      else
         $leap = false;
   }

   $gy += 4*div($g_day_no, 1461); /* 1461 = 365*4 + 4/4 */
   $g_day_no %= 1461;

   if ($g_day_no >= 366) {
      $leap = false;

      $g_day_no--;
      $gy += div($g_day_no, 365);
      $g_day_no = $g_day_no % 365;
   }

   for ($i = 0; $g_day_no >= $g_days_in_month[$i] + ($i == 1 && $leap); $i++)
      $g_day_no -= $g_days_in_month[$i] + ($i == 1 && $leap);
   $gm = $i+1;
   $gd = $g_day_no+1;

   return array($gy, $gm, $gd);
}

function jalali_week_day($j_y, $j_m, $j_d)
{
   global $j_days_in_month;

   $jy = $j_y-979;
   $jm = $j_m-1;
   $jd = $j_d-1;

   $j_day_no = 365*$jy + div($jy, 33)*8 + div($jy%33+3, 4);

   for ($i=0; $i < $jm; ++$i)
      $j_day_no += $j_days_in_month[$i];

   $j_day_no += $jd;

   return ($j_day_no + 2) % 7 + 1;
}

function jcheckdate($j_y, $j_m, $j_d)
{
   global $j_days_in_month;

   $j_y = tonumber($j_y);
   if ($j_y < 0 || $j_y > 32767 || $j_m < 1 || $j_m > 12 || $j_d < 1 || $j_d >
           ($j_days_in_month[$j_m-1] + ($j_m == 12 && !(($j_y-979)%33%4))))
       return false;
   return true;
}

function create_date($y, $m, $d)
{
   if ($y != '') {
      $y = 1300+(ord($y[1])-176)*10+(ord($y[3])-176);
      list($gy, $gm, $gd) = jalali_to_gregorian($y, $m, $d);
      return "$gy-$gm-$gd";
   }
   else {
      return date("Y-m-d");
   }
}

function two_months_ago($y, $m, $d)
{
   $ny = $y; $nm = $m - 2; $nd = $d;
   if ($nm < 1) {
      $ny--;
      $nm += 12;
   }
   while (!jcheckdate($ny, $nm, $nd)) {
      $nd--;
   }
   return array($ny, $nm, $nd);
}

function long_date($s) {
   global $monthname;

   list($y, $m, $d) = explode("-", $s);
   list($jy, $jm, $jd) = gregorian_to_jalali($y, $m, $d);
   return farsi($jd).farsi("_").$monthname[$jm].farsi("_").farsi($jy);
}

function short_date($s) {
   list($y, $m, $d) = explode("-", $s);
   list($jy, $jm, $jd) = gregorian_to_jalali($y, $m, $d);
   return "<span dir='ltr'>".farsi($jy)
          ."/".farsi($jm)."/".farsi($jd)."</span>";
}

}
?>
