CREATE TABLE  customer (
    cid		char(8)		not null,
    citycode	int4		not null,
    telnum	int4		not null,
    fname	varchar(100)	not null,
    lname	varchar(100)	not null,
    address	varchar(500)	not null,
  primary key	(cid),
  check		(citycode > 0),
  check		(telnum > 0)
);

CREATE TABLE  call (
    councode	int4		not null,
    citycode	int4		not null,
    telnum	int4		not null,
    starttime	timestamp	not null,
    length	int4		not null,
    cost	int4		not null,
    cid		char(8)		not null,
  primary key	(cid, starttime),
  foreign key	(cid) references customer (cid) on update cascade,
  check		(councode > 0),
  check		(citycode > 0),
  check		(telnum > 0),
  check		(cost >= 0),
  check		(length >= 0)
);

CREATE TABLE  service (
    vid		serial		not null,
    servicename	varchar(100)	not null,
    price	int4		not null,
  primary key	(vid),
  unique	(servicename),
  check		(price >= 0)
);

CREATE TABLE  serviceuse(
    cid		char(8)		not null,
    vid		int4		not null,
    starttime	date		not null,
    endtime	date,
  primary key	(cid, vid),
  foreign key	(cid) references customer (cid),
  foreign key	(vid) references service (vid)
);

CREATE TABLE  city (
    cityid	int4		not null,
    cityname	varchar(50)	not null,
  primary key	(cityid),
  check		(cityid > 0)
);

CREATE TABLE  citycost(
    fromcity	int4		not null,
    tocity	int4		not null,
    cost	int4		not null,
  primary key	(fromcity, tocity), 
  foreign key	(fromcity) references city(cityid),
  foreign key	(tocity) references city(cityid),
  check		(cost >= 0)
);

CREATE TABLE  foreigncost (
    countid	int4		not null,
    countname	varchar(50)	not null,
    cost	int4		not null,
  primary key	(countid),
  check		(cost >= 0)
);

CREATE TABLE  tax (
    mincost	int4		not null,
    percent	int2		not null,
  primary key	(mincost),
  check		(percent >= 0 and percent <= 100)
);

CREATE TABLE  const (
    constid	varchar(20)	not null,
    constname	varchar(200)	not null,
    value	int4		not null,
  primary key	(constid)
);
	
CREATE TABLE  sysuser (
	userid		serial		not null,
	fname		varchar(100)	not null,
	lname		varchar(100)	not null,
	login		varchar(50)	not null,
	password	varchar(100),
	isoperator	bool		not null default false,
	ismanager	bool		not null default false,
	isadmin		bool		not null default false,
	
	primary key (userid),
	unique (login)
);
